@@ -198,7 +198,7 @@ def _build_ascii_fmtstr(pc):
             self.point_cloud_to_fileobj(pc, f, mode)
 
 
-def point_cloud_to_fileobj(pc, fileobj, data_compression=None):
+def _point_cloud_to_fileobj(pc, fileobj, data_compression=None):
     """write pointcloud as .pcd to fileobj.
     if data_compression is not None it overrides pc.data.
     """
@@ -277,14 +277,14 @@ def _metadata_is_consistent(metadata):
     return ok
 
 
-def pc_from_path(fname):
+def _pc_from_path(fname):
     """load pcd and return a PointCloud instance"""
     with open(fname, "rb") as f:
         meta, pc = _point_cloud_from_fileobj(f)
         return PointCloud(meta, pc)
 
 
-def pc_concat(pc_list):
+def _pc_concat(pc_list):
     """concatenate multiple point clouds"""
     metas = [i.get_metadata() for i in pc_list]
     fields_unique = np.unique(np.array([i["fields"] for i in metas]), axis=0)
@@ -297,15 +297,17 @@ def pc_concat(pc_list):
     # all concat pc has same fields, size and type
     try:
         assert (
-        fields_unique.shape[0] == 1
-        and size_unique.shape[0] == 1
-        and type_unique.shape[0] == 1
-        and len(set(data_list)) == 1
-        # and len(set(width_list)) == 1
-        # and len(set(height_list)) == 1
-    )
+            fields_unique.shape[0] == 1
+            and size_unique.shape[0] == 1
+            and type_unique.shape[0] == 1
+            and len(set(data_list)) == 1
+            # and len(set(width_list)) == 1
+            # and len(set(height_list)) == 1
+        )
     except:
-        from IPython import embed; embed(colors='neutral')
+        from IPython import embed
+
+        embed(colors="neutral")
     meta = pc_list[0].get_metadata()
     meta["points"] = np.sum(points_list)
     meta["width"] = meta["points"]
@@ -342,13 +344,14 @@ class PointCloud:
     See `PCL docs <http://pointclouds.org/documentation/tutorials/pcd_file_format.php>`__
     for more information.
     """
+
     vis = PointCloudVisualizer()
+
     def __init__(self, metadata, pc_data):
         self.metadata_keys = metadata.keys()
         self.__dict__.update(metadata)
         self.pc_data = pc_data
         self.check_sanity()
-        
 
     def get_metadata(self):
         """returns copy of metadata"""
@@ -368,22 +371,6 @@ class PointCloud:
     def save_ascii(self, fname):
         self.save_pcd(fname, "ascii")
 
-    def draw_pcloud(
-        self,
-        color="gray",
-        r=0,
-        show=True,
-        save=False,
-        save_path=None,
-        draw_distance_marker=True,
-    ):
-        draw = self.vis.draw_pcloud(self.pc_data, color, r, draw_distance_marker)
-        if show:
-            self.vis.img_show(draw)
-        if save:
-            self.vis.img_save(draw, save_path)
-        return draw
-
     def draw_pcloud(
         self,
         color="gray",
@@ -395,8 +382,17 @@ class PointCloud:
         draw_orin_marker=True,
         auto_rot=True,
     ):
-        draw = self.vis.draw_pcloud(self.to_ndarray(['x','y']), color, r, draw_distance_marker, draw_orin_marker,show,auto_rot,save,save_path)
-
+        draw = self.vis.draw_pcloud(
+            self.to_ndarray(["x", "y"]),
+            color,
+            r,
+            draw_distance_marker,
+            draw_orin_marker,
+            show,
+            auto_rot,
+            save,
+            save_path,
+        )
         return draw
 
     def to_ndarray(self, fields=None):
@@ -434,7 +430,7 @@ class PointCloud:
             warnings.warn("data_compression keyword is deprecated for" " compression")
             compression = kwargs["data_compression"]
         with open(fname, "wb") as f:
-            point_cloud_to_fileobj(self, f, compression)
+            _point_cloud_to_fileobj(self, f, compression)
 
     def coor_trans(self, extr_mat):
         pc_data = self.pc_data.copy()
@@ -444,7 +440,7 @@ class PointCloud:
         y = pc_data["y"]
         z = pc_data["z"]
         xyz_1 = np.vstack((x, y, z, np.ones((1, x.shape[0]))))
-        #xyz_1 = np.vstack([xyz, np.ones((1, xyz.shape[1]))]) 
+        # xyz_1 = np.vstack([xyz, np.ones((1, xyz.shape[1]))])
         xyz_1_trans = np.dot(extr_mat, xyz_1)
         pc_trans = np.ascontiguousarray((xyz_1_trans[:3]).T)
 
@@ -454,33 +450,6 @@ class PointCloud:
         self.pc_data = pc_data
         return self
 
-
-    def coor_trans_old(self, extr_mat):
-        pc_data = self.pc_data.copy()
-        assert "x" in self.fields and "y" in self.fields and "z" in self.fields
-
-        x = pc_data["x"]
-        y = pc_data["y"]
-        z = pc_data["z"]
-        xyz = np.stack((x, y, z)).T
-
-        pc_trans = np.apply_along_axis(
-            self.homogene_transformation, axis=1, arr=xyz, homo_matr=extr_mat
-        )
-
-        pc_data["x"] = pc_trans[:, 0]
-        pc_data["y"] = pc_trans[:, 1]
-        pc_data["z"] = pc_trans[:, 2]
-        self.pc_data = pc_data
-        return self
-
-    def homogene_transformation(self, arr, homo_matr):
-        arr_xyz_homo = np.append(arr[:3], 1)
-        arr_xyz_trans = np.matmul(homo_matr, arr_xyz_homo)
-        arr_rest = arr[3:]
-        arr_ret = np.append(arr_xyz_trans[:3], arr_rest)
-        return arr_ret
-
     def copy(self):
         new_pc_data = np.copy(self.pc_data)
         new_metadata = self.get_metadata()
@@ -488,112 +457,8 @@ class PointCloud:
 
     @staticmethod
     def from_path(fname):
-        return pc_from_path(fname)
+        return _pc_from_path(fname)
 
     @staticmethod
     def pc_concat(pc_list):
-        return pc_concat(pc_list)
-
-
-def concat():
-    pc_dict = {}
-    path = Path("/Users/yuehao/Desktop/small_set_benz/output/9885806035")
-    for folder in path.iterdir():
-        if folder.is_dir() and "radar" in folder.name:
-
-            for file in folder.iterdir():
-                if file.suffix == ".pcd":
-                    pc_dict[folder.name] = pc_from_path(file).to_radar_ndarray()
-                    continue
-                    pc = pc_from_path(file).to_lidar_ndarray()
-                    print(pc.shape)
-                    pc_concat = np.concatenate((pc_concat, pc), axis=0)
-                    print(pc_concat.shape)
-    print(pc_dict)
-
-
-def demo_pcdtrans_concat():
-    # pcd1
-    pcd1 = pc_from_path(
-        "/Users/yuehao/Momenta/labeltest/sampled_data/436fcc645714492c68b42b5dd3ba80aa/1656923753.220280.360lidar.pcd"
-    )
-    # pcd2 with coor transformation
-    pcd2 = pc_from_path(
-        "/Users/yuehao/Momenta/labeltest/sampled_data/436fcc645714492c68b42b5dd3ba80aa/1656923753.220280.360lidar.pcd"
-    ).coor_trans(np.array([[1, 0, 0, 10], [0, 1, 0, 10], [0, 0, 1, 0], [0, 0, 0, 1]]))
-    pcd3 = pc_from_path(
-        "/Users/yuehao/Momenta/labeltest/sampled_data/436fcc645714492c68b42b5dd3ba80aa/1656923753.220280.360lidar.pcd"
-    ).coor_trans(np.array([[1, 0, 0, -10], [0, 1, 0, 10], [0, 0, 1, 0], [0, 0, 0, 1]]))
-    # concat pcd1 and pcd2
-    pcd_concat = pc_concat([pcd1, pcd2, pcd3])
-    pcd_concat.save_pcd("pcd_concat.pcd")
-    vis = PointCloudVisualizer()
-    bev_concat = vis.draw_pc_overlay(((pcd1, "gray", 0), (pcd2, "red", 1)))
-    vis.img_show(bev_concat)
-
-
-def demo_load_vis_pcd():
-    pcd1 = pc_from_path(
-        "/Users/yuehao/Momenta/labeltest/sampled_data/436fcc645714492c68b42b5dd3ba80aa/1656923753.220280.360lidar.pcd"
-    )
-    bev = pcd1.draw_pcloud(show=True)
-
-
-if __name__ == "__main__":
-
-    pcd = PointCloud.from_path('test.pcd')
-    pcd.save_ascii('test_ascii.pcd')
-
-
-    # # concat()
-    # # exit()
-    # pch = PointCloudHelper()
-    # vis = PointCloudVisualizer()
-    # #pcl = pc_from_path("/Users/yuehao/Desktop/small_set_benz/top_lidar/9885804720.pcd")
-    # #pcl2 = pc_from_path("/Users/yuehao/Desktop/small_set_benz/top_lidar/9885804720.pcd").coor_trans(np.array([[1, 0, 0, 110], [0, 1, 0, 100], [0, 0, 1, 0], [0, 0, 0, 1]]))
-    # pcr1 = pc_from_path('/Users/yuehao/Momenta/labeltest/sampled_data/436fcc645714492c68b42b5dd3ba80aa/1656923753.220280.360lidar.pcd')
-    # pcr2 = pc_from_path('/Users/yuehao/Momenta/labeltest/sampled_data/436fcc645714492c68b42b5dd3ba80aa/1656923753.220280.360lidar.pcd').coor_trans(np.array([[1, 0, 0, 10], [0, 1, 0, 10], [0, 0, 1, 0], [0, 0, 0, 1]]))
-    # pcr3 = pc_from_path('/Users/yuehao/Momenta/labeltest/sampled_data/436fcc645714492c68b42b5dd3ba80aa/1656923753.220280.360lidar.pcd').coor_trans(np.array([[1, 0, 0, 10], [0, 1, 0, 0], [0, 0, 1, 0], [0, 0, 0, 1]]))
-
-    # bev_lidar = vis.draw_pc_overlay(((pcr1, "gray", 0), (pcr2, "red", 1)))
-    # vis.img_show(bev_lidar)
-    # exit()
-    # pc_con = pc_concat([pcr1,pcr2,pcr3])
-
-    # draw = pc_con.draw_pcloud()
-    # #pcl.save_pcd('test.pcd')
-    # exit()
-
-    # # draw_radar=vis.draw_pcloud(pcr,'red',1)
-    # # vis.bev_show(draw_radar)
-
-    # # #pc_concat=np.concatenate((pcl[:,0:3],pcr[:,0:3]))
-    # # pc_concat = pc_from_path('/Users/yuehao/Desktop/small_set_benz/output/9885806035/merged_radar/9885806035.pcd').to_lidar_ndarray()
-    # # draw_radar=vis.draw_pcloud(pc_concat,'red',1)
-    # # vis.bev_show(draw_radar)
-    # # pc_lidar = pc_from_path('/Users/yuehao/Desktop/small_set_benz/output/9885806035/top_lidar/9885804720.pcd').to_lidar_ndarray()
-    # # pc_lidar_trans = pch.pc_transform(pc_lidar, np.array([[0.999894, 0.002756, -0.014267, 1.525952], [-0.002718, 0.999993, 0.002662, 1.031374], [0.014274, -0.002623, 0.999895,  2.37252], [0, 0, 0, 1]]))
-    # # draw=vis.draw_pcloud_overlay(((pc_lidar_trans,'gray', 0),(pc_concat,'red', 1)))
-    # # print(draw.shape)
-    # # vis.bev_show(draw)
-    # # exit()
-
-    # # bev_radar = vis.draw_pcloud(pc_concat,'red', 1)
-    # # bev_lidar = vis.draw_pcloud(pc_lidar,'gray', 0)
-    # # vis.bev_show(bev_radar)
-
-    # # pcr可以作为struct
-    # pcd = array2pcd(pcr[:,:3],field_names=["x", "y", "z"])
-    # pcd.save_pcd('save.pcd')
-
-    # bev_lidar = vis.draw_pcloud_overlay(((pcl, "gray", 0), (pcr, "red", 1)))
-    # vis.img_show(bev_lidar)
-
-    # # lpt=lpt[110:120]
-    # pc_trans = pch.pc_transform(pcl, np.array([[1, 0, 0, 0], [0, 1, 0, 0], [0, 0, 1, 0], [0, 0, 0, 1]]))
-
-    # draw = pch.draw_pcloud_single(pc_trans, "gray", 2)
-    # vis.img_show(draw)
-    # # dra_overlay = pch.draw_pcloud_overlay(((lpt, "gray", 0), (rpt, "red", 1)))
-    # # pch.image_save("save.png", draw_overlay)
-    # # pch.image_show(draw_overlay)
+        return _pc_concat(pc_list)
